slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSKrylovSchurSetRestart

Sets the restart parameter for the Krylov-Schur method, in particular the proportion of basis vectors that must be kept after restart.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSKrylovSchurSetRestart(EPS eps,PetscReal keep)

Logically Collective on eps

### Input Parameters

| eps | - the eigenproblem solver context
| keep | - the number of vectors to be kept at restart

### Options Database Key

| -eps_krylovschur_restart | - Sets the restart parameter

### Notes

Allowed values are in the range [0.1,0.9]. The default is 0.5.

### See Also

EPSKrylovSchurGetRestart()

### Level

advanced

### Location

src/eps/impls/krylov/krylovschur/krylovschur.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages